==> igniteui-react-charts-18.0.0.tgz: package/esm5/lib/igr-chart-series-event-args.js <==
import { IgrSeries } from "./igr-series";
/**
 * Represents event arguments for chart's SeriesAdded and SeriesRemoved events
*/
var IgrChartSeriesEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrChartSeriesEventArgs() {
    }
    Object.defineProperty(IgrChartSeriesEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrChartSeriesEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrChartSeriesEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrChartSeriesEventArgs.prototype, "series", {
        /**
         * Gets the series.
        */
        get: function () {
            if (this.i.series == null) {
                return null;
            }
            if (!this.i.series.externalObject) {
                var e = IgrSeries._createFromInternal(this.i.series);
                if (e) {
                    e._implementation = this.i.series;
                }
                this.i.series.externalObject = e;
            }
            return this.i.series.externalObject;
        },
        set: function (v) {
            v == null ? this.i.series = null : this.i.series = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrChartSeriesEventArgs;
}());
export { IgrChartSeriesEventArgs };

==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/igr-chart-series-event-args.js <==
import { IgrSeries } from "./igr-series";
/**
 * Represents event arguments for chart's SeriesAdded and SeriesRemoved events
*/
var IgrChartSeriesEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrChartSeriesEventArgs() {
    }
    Object.defineProperty(IgrChartSeriesEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrChartSeriesEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrChartSeriesEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrChartSeriesEventArgs.prototype, "series", {
        /**
         * Gets the series.
        */
        get: function () {
            var r = this.i.series;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrSeries._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.series = null : this.i.series = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrChartSeriesEventArgs;
}());
export { IgrChartSeriesEventArgs };
